import { AsyncStorage } from 'react-native';
import BumbleConfig from './BumbleConfig';
import PushNotificationIOS from "@react-native-community/push-notification-ios";
import { AppConstants } from './constants';


class APNSMessagingService {

    checkPermission() {
        return new Promise((resolve, reject) => {
            this.onRegistered = this.onRegistered.bind(this)
            PushNotificationIOS.addEventListener('register', this.onRegistered);
            PushNotificationIOS.addEventListener(
                'registrationError',
                this.onRegistrationError,
            );
            PushNotificationIOS.addEventListener('notification', this.onRemoteNotificationAPNS);
            PushNotificationIOS.requestPermissions().then(
                async data => {
                    // data=PushNotificationIOS.addEventListener('register', this.onRegistered);
                    let token;
                    let again = 0;
                    let interval = setInterval(() => {
                        token = this.getToken();
                        again = again + 1;
                        console.log("======>>>>.", token)
                        if (token) {
                            clearInterval(interval)
                            resolve(token)
                        } else {
                            if (again > 3)
                                clearInterval(interval)
                        }
                    }, 100)


                    console.log('PushNotificationIOS.requestPermissions', data);
                },
                data => {
                    console.log('PushNotificationIOS.requestPermissions failed', data);
                },
            );
        })
    }

    onRegistered(deviceToken) {
        console.log("===>>>", deviceToken)
        this.token = deviceToken;
    };

    getToken() {
        return this.token;
    }

    onRegistrationError(error) {
        console.log("==<<<<<<<<<",
            'Failed To Register For Remote Push',
            `Error (${error.code}): ${error.message}`,
            [
                {
                    text: 'Dismiss',
                    onPress: null,
                },
            ])
    };


    onRemoteNotificationAPNS(notification) {
        console.log("NOTIFICATION RECEIVED:", notification.getMessage())
        let message = notification._data;
        if (BumbleConfig.isBumbleNotification(message)) {
        //   if (HippoConfig.isHippoCallNotification({message:message})) {
        //     let messageJson = message.message;
        //     messageJson = JSON.parse(messageJson);
        //     messageJson['last_sent_by_full_name'] = messageJson.full_name;
        //     messageJson['new_message'] = 'RINGING...';
        //     if (messageJson.video_call_type == 'START_CALL') {
        //       // console.log('MESSAagesss');
        //       HippoConfig.createNotification(messageJson);
        //     }
        //   } else {
              message = message;
              BumbleConfig.createNotification(message);
        //   }
        } else {
          // Your logic goes here
        }
    };
}



const APNSService = new APNSMessagingService();
export default APNSService;