import { Alert, AsyncStorage } from 'react-native';
import firebase from 'react-native-firebase';
import { AppConstants } from './constants';
import BumbleConfig from './BumbleConfig';


// import HippoConfig from './../../Hippo_ReactNative_SDK/src/component/sdk/hippoConfig';

class FirebaseMessagingService {
  async checkPermission() {
    return new Promise(async (resolve, reject) => {
      const enabled = await firebase.messaging().hasPermission();
      if (enabled) {
        let token = await this.getToken();
        resolve(token);
      } else {
        resolve(this.requestPermission());
      }
    });
  }

  async requestPermission() {
    return new Promise(async (resolve, reject) => {
      try {
        await firebase.messaging().requestPermission();

        if (!firebase.messaging().isRegisteredForRemoteNotifications) {
          await firebase.messaging().registerForRemoteNotifications();
        }

        let fcmToken = await this.getToken();
        resolve(fcmToken);
      } catch (error) {
        // console.log('permission rejected');
        resolve(0);
      }
    });
  }

  async getToken() {
    return new Promise(async (resolve, reject) => {
      let fcmToken = await AsyncStorage.getItem(AppConstants.deviceToken);
      // console.log('FCM TOKEN:', fcmToken);
      if (!fcmToken) {
        fcmToken = await firebase.messaging().getToken();
        resolve(fcmToken);
        // console.log('FCM TOKEN:', fcmToken);
        if (fcmToken) {
          await AsyncStorage.setItem(AppConstants.deviceToken, fcmToken);
        }
      } else {
        resolve(fcmToken);
      }
    });
  }

  async createNotificationListeners() {

  
    this.messageListener = firebase.messaging().onMessage(async message=> {
      
      //  message = message._data.message;

      try {
        console.log("onMessage>>>>>>>>>>>>",message)
        BumbleConfig.createNotification(message);
      } catch (e) {
        console.log(e);
      }
    });

    /*
  * Triggered when a particular notification has been received in foreground
  * */
    this.notificationListener = firebase.notifications().onNotification((notification) => {
      console.log("onNotification",">>>>>>>>onNotification")

      BumbleConfig.createNotification(notification);
    });

    /*
    * If your app is in background, you can listen for when a notification is clicked / tapped / opened as follows:
    * */
    this.notificationOpenedListener = firebase.notifications().onNotificationOpened((notificationOpen) => {
      const { title, body } = notificationOpen.notification;
      // this.showAlert(title, body);
      this.props.navigation.push('Annoncements');

    });

    /*
    * If your app is closed, you can check if it was opened by a notification being clicked / tapped / opened as follows:
    * */
    const notificationOpen = await firebase.notifications().getInitialNotification();
    if (notificationOpen) {
      const { title, body } = notificationOpen.notification;
      // this.showAlert(title, body);
      this.props.navigation.push('Annoncements');

    }




  }

  async componentOnMountt() {
    this.notificationListener();
    this.notificationOpenedListener();
  }

  async componentWillUnmountt() {
    this.notificationListener();
    this.notificationOpenedListener();
  }
  showAlert(title, body) {
    Alert.alert(
      title, body,
      [
        { text: 'OK' },
      ],
      { cancelable: false },
    );
  }
}

const FirebaseService = new FirebaseMessagingService();
export default FirebaseService;
