import React, { Component, PureComponent } from 'react';
import {
    PropTypes,
    TextInput, Button,
    StyleSheet, TouchableOpacity,
    View, Text, AsyncStorage, Image, Animated
} from 'react-native';
import dimens from '../Values/dimens';
import colors from '../Values/colors';
import ApiServiceList from '../moduels/APiServiceList';
import { showAlert, AppConstants } from '../Utils/constants';
import { FlatList } from 'react-native-gesture-handler';
import TextUtils from '../Utils/textUtils';
import { SafeAreaView } from 'react-native-safe-area-context';
import CardView from 'react-native-cardview';
import Moment from 'moment';
import ViewMoreText from 'react-native-view-more-text';
import { SwipeListView } from 'react-native-swipe-list-view';


const rowSwipeAnimatedValues = {};

export default class Annoncements extends Component {


    constructor(props) {
        super(props);
        this.state = {
            result: [],
            listViewData: {},
        };
        this._showClear();
    }



    componentDidMount() {
        // const { setParams } = this.props.navigation;

        this.getAnnouncements();
    }

    _showClear() {
        console.log("_showClear>>>>>>>>>>>>>>>")
        this.props.navigation.setParams({
            clear: this._onClearClick.bind(this)
        });
    }


    _onClearClick() {
        //hit api
        console.log("clearall>>>>>>>>>>>>>>>")
        this.deleteAnnouncements(0, 1);
    }

    render() {
        return (
            <View
                style={styles.container}>
                {this.renderList(this.state.result)}

            </View >
        )
    }
    renderList = (result) => {
        const { state } = this.props.navigation;

        console.log("result>>", result.length);
        return (

            <SafeAreaView>
                {/* <FlatList
                    keyExtractor={(item, index) => item.channel_id}
                    onEndReachedThreshold={0.5}
                    data={result}
                    renderItem={this._renderItem}
                /> */}

                <SwipeListView
                    data={this.state.listViewData}
                    renderItem={this._renderItem}
                    renderHiddenItem={this.renderHiddenItem}
                    leftOpenValue={0}
                    rightOpenValue={-80}
                    previewRowKey={'0'}
                    // previewOpenValue={-40}
                    previewOpenDelay={3000}
                    onRowDidOpen={this.onRowDidOpen}
                    onSwipeValueChange={this.onSwipeValueChange}
                />

            </SafeAreaView>

        );
    };
    _renderItem = ({ item }) => {


        return <ListItem
            key={item.value.channel_id}
            channel_id={item.value.channel_id}
            created_at={item.value.created_at}
            description={item.value.description}
            disable_reply={item.value.disable_reply}
            title={item.value.title}
            user_id={item.value.user_id}
            imageURL={JSON.parse(JSON.stringify(item.value.custom_attributes)).image.image_url}

        />
    };

    onRowDidOpen = rowKey => {
        console.log('This row opened', rowKey);
    };

    onSwipeValueChange = swipeData => {
        const { key, value } = swipeData;
        rowSwipeAnimatedValues[key].setValue(Math.abs(value));
    };
    closeRow(rowMap, rowKey) {
        if (rowMap[rowKey]) {
            rowMap[rowKey].closeRow();
        }
    }

    deleteRow(rowMap, rowKey) {

        this.closeRow(rowMap, rowKey);
        const newData = [...this.state.listViewData];
        const prevIndex = this.state.listViewData.findIndex(
            item => item.key === rowKey
        );

        this.deleteAnnouncements(rowKey, 0)
        // newData.splice(prevIndex, 1);
        // this.setState({ listViewData: newData });
    }

    renderHiddenItem = (data, rowMap) => {
        return <View
            key={data.item.value.channel_id}
            style={styles.rowBack}>
            <TouchableOpacity
                style={[styles.backRightBtn, styles.backRightBtnRight]}
                onPress={() => this.deleteRow(rowMap, data.item.value.channel_id)}
            >
                <Animated.View
                    style={[
                        {
                            transform: [
                                {
                                    scale: rowSwipeAnimatedValues[
                                        data.item.value.channel_id
                                    ].interpolate({
                                        inputRange: [45, 90],
                                        outputRange: [0, 1],
                                        extrapolate: 'clamp',
                                    }),
                                },
                            ],
                        },
                    ]}
                >
                    <Text style={styles.backTextWhite}>CLEAR</Text>
                </Animated.View>
            </TouchableOpacity>
        </View>
    };

    async getAnnouncements() {

        let app_secret_key = await AsyncStorage.getItem("app_secret_key");
        let en_user_id = await AsyncStorage.getItem("en_user_id");
        let user_id = await AsyncStorage.getItem("user_id");

        const obj = {
            app_secret_key: app_secret_key,
            en_user_id: en_user_id,
            user_id: user_id
        };

        ApiServiceList.AnouncementsListApi(obj)
            .then(res => {

                Array(res.data.length)
                    .fill('')
                    .forEach((_, i) => {

                        rowSwipeAnimatedValues[res.data[i].channel_id] = new Animated.Value(0);
                    });
                this.setState({
                    result: res.data,
                    listViewData: Array(res.data.length)
                        .fill('')
                        .map((_, i) => ({ key: res.data[i].channel_id, value: res.data[i] }))
                });
            });
    }
    async deleteAnnouncements(channel_id, isAll) {

        let app_secret_key = await AsyncStorage.getItem("app_secret_key");
        let en_user_id = await AsyncStorage.getItem("en_user_id");
        let user_id = await AsyncStorage.getItem("user_id");
        console.log("deleteAnnouncements>>>", channel_id)
        const obj = {
            delete_all_announcements: isAll,
            en_user_id: en_user_id,
            app_secret_key: app_secret_key,
            user_id: user_id,

        };

        if (isAll === 0) {
            obj.channel_ids = [channel_id]
        }
        ApiServiceList.ClearCampaign(obj)
            .then(res => {
                console.log(res);
                this.getAnnouncements();
            });
    }
}




class ListItem extends PureComponent {

    render() {
        return (
            <CardView
                cardElevation={5}
                cardMaxElevation={5}
                cornerRadius={5}
                style={styles.cardViewStyle}>

                <View style={styles.holder}>

                    <View style={styles.vertical}>
                        <Text style={styles.textBold}>{this.props.title}</Text>

                        <ViewMoreText
                            fontFamily='ProximaNova-Regular'
                            numberOfLines={3}
                            renderViewMore={this.renderViewMore}
                            renderViewLess={this.renderViewLess}
                        >
                            <Text style={styles.text}>{this.props.description} </Text>
                        </ViewMoreText>

                        <Text style={styles.textDate}>{Moment(this.props.created_at).format('d MMM yy hh:mm a')} </Text>
                        {this.props.imageURL !== null ? <Image source={{ uri: this.props.imageURL }} style={{ height: 130, resizeMode: 'cover', marginTop: 8, borderRadius: 8 }} />
                            : null}

                    </View>

                </View>
            </CardView>
        );
    }

}



const styles = StyleSheet.create({

    container: {
        flex: 1
    },
    iconStyle: {

        backgroundColor: colors.colorAccent,
        width: 10,
        height: 10,
        borderRadius: 32 / 2,

    },

    text: {
        fontSize: 18,
        alignItems: 'center',
        color: '#5a5a5a',
        fontFamily: 'ProximaNova-Regular'

    },
    textDate: {
        fontSize: 14,
        alignItems: 'center',
        color: '#858585',
        marginTop: 5,
        // fontFamily: 'Proxima Nova Alt Light'

    },
    viewMore: {
        fontSize: 12,
        alignItems: 'center',
        color: '#5b9f0d',
        textAlign: 'right'

    }, textBold: {
        fontSize: 18,
        alignItems: 'center',
        fontWeight: "bold",
        // fontFamily: 'Proxima Nova Alt Bold'
    },
    holder: {
        flexDirection: 'row', padding: dimens.dp_14,
        alignItems: 'center'
    },

    vertical: { flex: 1, flexDirection: 'column' },
    idTextStyle: {
        fontSize: dimens.text_medium,
        color: colors.text_color,
        fontFamily: 'Lato-Semibold',
        alignSelf: 'center',
        textAlign: 'right',
    },
    noDataHolder: {
        flex: 1,
        alignContent: 'center',
        justifyContent: 'center',
    },
    assignFlex: {
        flex: 1,
    }, noResultText: {
        padding: dimens.dp_6,
        fontSize: dimens.text_large,
        color: colors.text_color,
        alignSelf: 'center',
    }, cardViewStyle: {
        backgroundColor: '#ffffff',
        margin: 8
    }, backRightBtn: {
        alignItems: 'center',
        bottom: 0,
        justifyContent: 'center',
        position: 'absolute',
        top: 0,
        width: 80,
    },
    backRightBtnLeft: {
        backgroundColor: 'blue',
        right: 80,
    },
    backRightBtnRight: {
        backgroundColor: 'red',
        right: 0,
    }, backTextWhite: {
        color: '#FFF',
        fontSize: 20
    }, rowBack: {
        alignItems: 'center',
        backgroundColor: '#DDD',
        flex: 1,
        margin: 10,
        flexDirection: 'row',
        justifyContent: 'space-between',
        paddingLeft: 15,
        fontFamily: 'ProximaNova-Regular'

    }
})